bbemkr-package: Bayesian bandwidth estimation for multivariate kernel regression with Gaussian error
Description
Bayesian bandwidth estimation for Nadaraya-Watson type multivariate kernel regression with Gaussian errorDetails
This package designs for selecting bandwidths used in the Nadaraya-Watson kernel regression estimator.
Assuming the i.i.d residuals that are uncorrelated to the regressors and follow normal distribution,
the bandwidths are selected using Markov chain Monte Carlo (MCMC) method, in particular the random-walk Metropolis algorithm.References
X. Zhang and R. D. Brooks and M. L. King (2009) A Bayesian approach to bandwidth selection for multivariate kernel regression with an application to state-price density estimation,
Journal of Econometrics, 153, 21-32.
X. Zhang and M. L. King and R. J. Hyndman (2006) A Bayesian approach to bandwidth selection for multivariate kernel density estimation,
Computational Statistics and Data Analysis, 50, 3009-3031.