Learn R Programming

bbemkr (version 1.1)

bbewarmup: Burn-in period

Description

To minimize the cost value, it estimates the bandwidths of the regressors and variance parameter of the error density for the warmup or burn-in period.

Usage

bbewarmup(x, costpara, warm = 4, sizep = 2)

Arguments

x
Log bandwidths of the regressors
costpara
Initial cost value
warm
Number of iterations in the warmup or burn-in period
sizep
Tuning parameter used in the random-walk Metropolis algorithm

Value

  • xhLog bandwidths of the regressors, after the warmup period
  • xhtestLog bandwidths of the regressors, during the warmup period
  • sigmaVariance of the error density, after the warmup period
  • sigmatestVariance of the error density, during the warmup period
  • costCost value, after the warmup period
  • costtestCost value, during the warmup period
  • accept_rateAcceptance rate of the random-walk Metropolis algorithm

See Also

bbeMCMCrecording, bbelogdensity