gibbs_admkr_nw: Estimating bandwidths of the regressors
Description
Implements the random-walk Metropolis algorithm to estimate the bandwidths of the regressorsUsage
gibbs_admkr_nw(xh, inicost, k, mutsizp, prob, data_x, data_y)
Arguments
xh
Log of square bandwidths in the regression function
mutsizp
Step size of random-walk Metropolis algorithm
prob
Optimal convergence rate for drawing single or multiple parameters
Value
- xEstimated bandwidths of the regression function
- costCost value, that is negative of log posterior
- accept_hAccept or reject.
accept_h=1 indicates acceptance, while accept_h=0 indicates rejection. - mutsizpStep size of the random-walk Metropolis algorithm
Details
1) The log bandwidths of the regressors are initialized using the normal reference rule of Silverman (1986).
2) Conditioning on the variance parameter of the error density, we implement random-walk Metropolis
algorithm to update the bandwidths, in order to achieve the minimum cost value.
3) The bandwidth of the kernel-form error density can be directly sampled.
4) Iterate steps 2) and 3) until the cost value is minimized.
5) Check the convergence of the parameters by examining the simulation inefficient factor (sif) value.
The smaller the sif value is, the better convergence of the parameters is.References
X. Zhang and R. D. Brooks and M. L. King (2009) A Bayesian approach to bandwidth selection for multivariate kernel regression with an application to state-price density estimation, Journal of Econometrics, 153, 21-32.
B. W. Silverman (1986) Density Estimation for Statistics and Data Analysis. Chapman and Hall, New York.