Learn R Programming

bbemkr (version 1.6)

mcmcrecord_admkr: MCMC iterations

Description

Estimated averaged bandwidths of the regressors of the kernel-form error density

Usage

mcmcrecord_admkr (x, inicost, mutsizp, errorsizp, warm = 100, M = 100, prob = 0.234, 
    errorprob = 0.44, num_batch = 10, step = 10, data_x, data_y, xm, alpha = 0.05, 
      mlike = c("Chib", "Geweke", "LaplaceMetropolis", "all"))

Arguments

x
Log of square bandwidth
inicost
Initial cost value
mutsizp
Step size of random-walk Metropolis algorithm. At each iteration, the value of mutsizp will alter depending on acceprance or rejection. As the number of iteration increases, the final acceptance probability will converge to the optimal rate,
errorsizp
Step size of random-walk Metropolis algorithm. At each iteration, the value of errorsizp will alter depending on acceprance or rejection. As the number of iteration increases, the final acceptance probability will converge to the optimal rate
warm
Burn-in period
M
Number of MCMC iteration
prob
Optimal acceptance rate of random-walk Metropolis algorithm for the regression function
errorprob
Optimal acceptance rate of random-walk Metropolis algorithm for the error density
num_batch
Number of batch samples
step
Recording value at a specific step, in order to achieve iid samples and eliminate correlation
data_x
Regressors
data_y
Response variable
xm
Values of true regression function
alpha
Quantile of the critical value in calculating Geweke's log marginal likelihood
mlike
Method for calculating log marginal likelihood

Value

  • sum_hEstimated parameters in an order of the bandwidths of the regressors, the variance parameter of the error density and cost value
  • h2Estimated parameters in an order of the square bandwidths of the regressors, the square variance parameter of the error density
  • sifSimulation inefficient factor. The small it is, the better the method is in general
  • mutsizpStep size of random-walk Metropolis algroithm for each iteration of MCMCrecord
  • cpostSimulation output of square bandwidths obtained from MCMC
  • ghostSimulation output of square bandwidths obtained from MCMC
  • accept_nwAcceptance rate of random-walk Metropolis algorithm for the regression function
  • accept_erroAcceptance rate of random-walk Metropolis algorithm for the kernel-form error density
  • marginalikeLog marginal likelihood
  • R2R square
  • MSEMean square error

Details

Akin to the burn-in period, it determines the retained bandwidths for the regressors and the variance of the error density for finite samples. It also calculates the simulation inefficient factor (SIF) value, R square, mean square error, and log marginal density by Chib (1995), Geweke (1999) and the Laplace Metropolis method describe in Raftery (1996).

References

H. L. Shang (2013) Bayesian bandwidth estimation for a semi-functional partial linear regression model with unknown error density, Computational Statistics, in press.

H. L. Shang (2013) Bayesian bandwidth estimation for a nonparametric functional regression model with unknown error density, Computational Statistics and Data Analysis, 67, 185-198.

X. Zhang and R. D. Brooks and M. L. King (2009) A Bayesian approach to bandwidth selection for multivariate kernel regression with an application to state-price density estimation, Journal of Econometrics, 153, 21-32.

S. Chib and I. Jeliazkov (2001) Marginal likelihood from the Metropolis-Hastings output, Journal of the American Statistical Association, 96, 453, 270-281.

S. Chib (1995) Marginal likelihood from the Gibbs output, Journal of the American Statistical Association, 90, 432, 1313-1321.

M. A. Newton and A. E. Raftery (1994) Approximate Bayesian inference by the weighted likelihood bootstrap (with discussion), Journal of the Royal Statistical Society, 56, 3-48.

J. Geweke (1998) Using simulation methods for Bayesian econometric models: inference, development, and communication, Econometric Reviews, 18(1), 1-73.

A. E. Raftery (1996) Hypothesis testing and model selection, in Markov Chain Monte Carlo In Practice by W. R. Gilks, S. Richardson and D. J. Spiegelhalter, Chapman and Hall, London.

See Also

logdensity_admkr, logpriors_admkr, loglikelihood_admkr, warmup_admkr