bbecost: Negative of log posterior
Description
Calculates the negative of log posterior, using the leave-one-out samples.Usage
bbecost(data_x, data_y, x, bandx_priors, prior_p = 2, prior_st = 0.1)
Arguments
x
Log bandwidths of the regressors
bandx_priors
Prior information
prior_p
Tuning parameter of the prior following inverse gamma distribution
prior_st
Tuning parameter of the prior following inverse gamma distribution
Value
- Value of the cost function
Details
The default bandx_priors is the inverse gamma distribution.References
X. Zhang and R.D. Brooks and M.L. King (2009), A Bayesian approach to bandwidth selection for multivariate kernel regression with an application to state-price density estimation, Journal of Econometrics, 153, 21-32.